===================================
Welcome to datapkg's documentation!
===================================

datapkg is a tool for distributing, discovering and installing knowledge
(data and content) 'packages'.

datapkg is a *simple* way to 'package' data building on *existing* packaging
tools developed for code. datapkg is designed to integrate closely with the
`CKAN (Comprehensive Knowledge Archive Network) <http://www.ckan.net/>`_.

By putting data in a package, it gets labelled with standardized metadata and
can be put in a datapkg repository, such as CKAN or a local one. Once in such
a repository, the packages are easy to find and retrieve.

Installation
============

.. toctree::

   install

Getting Started: Users
======================

We recommend users get started by taking a look at the manual:

.. toctree::

   manual

Getting Started: Developers
===========================

Source mercurial repository can be found at:
http://knowledgeforge.net/ckan/datapkg

For developers we recommend starting with the design document:

.. toctree::

   design

There are also a set of use cases and research on other similar tools:

.. toctree::

   usecases
   research

Other material
==============

.. toctree::

   license
   CHANGELOG
   external

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

